import type { InboundMessageContext } from '../../../agent/models/InboundMessageContext';
import type { Query } from '../../../storage/StorageService';
import type { EncryptedMessage } from '../../../types';
import type { ForwardMessage, MediationRequestMessage } from '../messages';
import { AgentConfig } from '../../../agent/AgentConfig';
import { EventEmitter } from '../../../agent/EventEmitter';
import { Wallet } from '../../../wallet/Wallet';
import { ConnectionService } from '../../connections';
import { KeylistUpdateMessage, MediationGrantMessage, KeylistUpdateResponseMessage } from '../messages';
import { MediationRecord } from '../repository/MediationRecord';
import { MediationRepository } from '../repository/MediationRepository';
import { MediatorRoutingRepository } from '../repository/MediatorRoutingRepository';
export declare class MediatorService {
    private agentConfig;
    private mediationRepository;
    private mediatorRoutingRepository;
    private wallet;
    private eventEmitter;
    private connectionService;
    private _mediatorRoutingRecord?;
    constructor(mediationRepository: MediationRepository, mediatorRoutingRepository: MediatorRoutingRepository, agentConfig: AgentConfig, wallet: Wallet, eventEmitter: EventEmitter, connectionService: ConnectionService);
    initialize(): Promise<void>;
    private getRoutingKeys;
    processForwardMessage(messageContext: InboundMessageContext<ForwardMessage>): Promise<{
        mediationRecord: MediationRecord;
        encryptedMessage: EncryptedMessage;
    }>;
    processKeylistUpdateRequest(messageContext: InboundMessageContext<KeylistUpdateMessage>): Promise<KeylistUpdateResponseMessage>;
    createGrantMediationMessage(mediationRecord: MediationRecord): Promise<{
        mediationRecord: MediationRecord;
        message: MediationGrantMessage;
    }>;
    processMediationRequest(messageContext: InboundMessageContext<MediationRequestMessage>): Promise<MediationRecord>;
    findById(mediatorRecordId: string): Promise<MediationRecord | null>;
    getById(mediatorRecordId: string): Promise<MediationRecord>;
    getAll(): Promise<MediationRecord[]>;
    findAllByQuery(query: Query<MediationRecord>): Promise<MediationRecord[]>;
    private updateState;
    private emitStateChangedEvent;
    private updateUseDidKeysFlag;
}
